==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/SprawozdaniePodpowiedz.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.enums.TypSprawozdaniaPodpowiedz;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class SprawozdaniePodpowiedz extends GenericDPSObject {
    /**
     * SPRAWOZDANIE_PODPOWIEDZ.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * SPRAWOZDANIE_PODPOWIEDZ.TYP
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private TypSprawozdaniaPodpowiedz typ;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return SPRAWOZDANIE_PODPOWIEDZ.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * SPRAWOZDANIE_PODPOWIEDZ.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return SPRAWOZDANIE_PODPOWIEDZ.TYP
     * @mbggenerated 2014-03-10 10:45:37
     */
    public TypSprawozdaniaPodpowiedz getTyp() {
        return typ;
    }

    /**
     * SPRAWOZDANIE_PODPOWIEDZ.TYP
     *
     * @param typ
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setTyp(TypSprawozdaniaPodpowiedz typ) {
        this.typ = typ;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        SprawozdaniePodpowiedz other = (SprawozdaniePodpowiedz) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getTyp() == null ? other.getTyp() == null : this.getTyp().equals(other.getTyp()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getTyp() == null) ? 0 : getTyp().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", typ=").append(typ);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/SprawozdaniePodpowiedz.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.enums.TypSprawozdaniaPodpowiedz;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class SprawozdaniePodpowiedz extends GenericDPSObject {
    /**
     * SPRAWOZDANIE_PODPOWIEDZ.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * SPRAWOZDANIE_PODPOWIEDZ.TYP
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private TypSprawozdaniaPodpowiedz typ;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return SPRAWOZDANIE_PODPOWIEDZ.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * SPRAWOZDANIE_PODPOWIEDZ.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return SPRAWOZDANIE_PODPOWIEDZ.TYP
     * @mbggenerated 2014-03-13 16:02:38
     */
    public TypSprawozdaniaPodpowiedz getTyp() {
        return typ;
    }

    /**
     * SPRAWOZDANIE_PODPOWIEDZ.TYP
     *
     * @param typ
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setTyp(TypSprawozdaniaPodpowiedz typ) {
        this.typ = typ;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        SprawozdaniePodpowiedz other = (SprawozdaniePodpowiedz) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getTyp() == null ? other.getTyp() == null : this.getTyp().equals(other.getTyp()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getTyp() == null) ? 0 : getTyp().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", typ=").append(typ);
        sb.append("]");
        return sb.toString();
    }
}
